@@ -3,7 +3,7 @@ use base 'Catalyst::Base';
 
 
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 
 
@@ -122,11 +122,14 @@ L<edit>, etc.
 There is a set of default TT templates to display the Model
 objects. You can override templates per Controller.
 
+There are helpers provided for creating these components. In most
+cases you'll have to provide some meta data for the table.
+
 
 =head2 Providing Meta Data
 
 Refactoring meant moving details out of templates and into general
-components. Sometimes this involved moving metadata out of the
+components. Sometimes this involved moving meta data out of the
 application.
 
 This information must be provided somehow, and the best we can do (if
@@ -205,6 +208,31 @@ lingering in the Location field in the browser (what happens when the
 user reloads the /book/destroy/34 URL? It fails if course).
 
 
+=head2 Forwarding between Controllers
+
+Each Controller has a Model class associated with it (available the
+$c->stash->{crud}->{model_class}), along with the rest of the meta
+data you set up in the Model class.
+
+The stash contents is set automatically in the C<auto> action when the
+request comes in. This is the current Controller (and it's Model).
+
+So long as you forward to CRUD actions in the same Controller, this is
+fine.
+
+But if you for some reason would like to forward to a CRUD action in
+another controller, you need to tell Enzyme to switch to a new current
+Controller. If the original request was for C</genre/add_book> and you
+would like to forward to C</book/add>, you would have to do this:
+
+    $c->forward("/book/set_crud_controller");
+    $c->forward("/book/add");
+
+The templates use the C<c.uri_for_controller('action')> helper method
+(from L<Catalyst::Enzyme::CRUD::View>) to force the URIs to the
+current Controller.
+
+
 =head2 Internationalization
 
 Not supported at the moment. There are a few texts coming from the
@@ -226,6 +254,37 @@ application.
 
 
 
+=head1 UPGRADING ENZYME
+
+=head2 Tables
+
+When you have created a new table, run the Model helper again, and it
+will create a Model class for the new table.
+
+It will also generate Model classes for the existing tables, but with
+a .new extension. Just delete them.
+
+
+=head2 Templates
+
+When you want to install a new version of Catalyst::Enzyme, the thing
+most likely to break is the templates. That's natural, that's the part
+you most likely will have changed.
+
+When that happens, re-generate the View, and merge any newly generated
+files with a .new suffix. If your files are in version control, the
+simplest thing may be to delete the templates, re-generate them and
+let the VCS help you merge them.
+
+This is of course a slight annoyance, but I'll try to bundle template
+changes into one release instead of many small ones. Template changes
+is bound to happen less frequently over time as the feature-set of the
+framework becomes more stable.
+
+Any template change will be noted in the L<Changes> file.
+
+
+
 =head1 TUTORIAL
 
 Let's take the Catalyst example BookDB application and see what it
@@ -252,7 +311,7 @@ else, open up a shell in C<tutorial> and go ahead...
     ... created files ...
     cd BookShelf
 
-Run test
+Run tests
 
     prove -Ilib t
 
@@ -279,19 +338,21 @@ and replace it with
 
     $c->res->redirect("/book");
 
-This url doesn't exist yet, but we'll create it soon (so don't try to
-restart the server just yet).
+This url doesn't exist yet, but we'll create it soon (so don't restart
+the server just yet).
 
-Note that the test t/01app.t will fail from now on since a redirect
-isn't is_success. Figure out what
+Note that the test C<t/01app.t> will fail from now on. Figure out
+what:
 
     prove -Ilib -v t\01app.t
 
-Since that test doesn't reflect what the application does anymore, you
-should probably change it to this:
+Ok, a redirect isn't C<is_success>. Since that test doesn't reflect
+what the application does anymore, you should probably change
+C<t/01app.t> to this:
 
     use Test::More tests => 1;
     use_ok( Catalyst::Test, 'BookShelf' );
+    ok(request("/")->is_redirect, "Redirect ok");
 
 And the test pass again. That's nice.
 
@@ -304,7 +365,8 @@ And the test pass again. That's nice.
     ... created files ...
 
 This creates a special Enzyme TT View, standard templates in
-./root/base/, as well as a css file in ./root/static/css/ .
+./root/base/, as well as a css (named after your application) file in
+./root/static/css/ .
 
 The Enzyme TT View allows for overloading template fragments based on
 the Controller (e.g. BookShelf::Controller::Book). It also provides a few
@@ -323,10 +385,7 @@ alter the web pages for only that part of the application.
 
 The bookdb.sql file is available in the C<t/tutorial/database>
 directory. It's probably a good idea to take a look at it to get an
-idea of what it provides. The foreign key relationships are especially
-interesting.
-
-Note: Make sure you have L<DBI::Shell> installed before running C<dbish>.
+idea of what it provides.
 
     mkdir db
     dbish dbi:SQLite:dbname=db/bookshelf.db < ..\database\bookdb.sql
@@ -353,6 +412,25 @@ Add Add Class::DBI configuration:
 
     __PACKAGE__->columns(Stringify => "title");
 
+
+The helper created the C<view_columns> and C<list_columns> from the
+fields in the table. You're supposed to remove or change the order of
+the columns to fit your application (if you like it the way it is,
+just delete the lines altogether).
+
+    #__PACKAGE__->columns(view_columns => qw/ author borrowed borrower format genre isbn pages publisher title year /);
+    #__PACKAGE__->columns(list_columns => qw/ author borrowed borrower format genre isbn pages publisher title year /);
+
+A third column group you can define here is C<edit_columns> (if not,
+the C<view_columns> is used for the add/edit as well).
+
+For the Book Model, reorder the C<view_columns>, and remove a few
+columns from the C<list_columns> to avoid clutter:
+
+    __PACKAGE__->columns(list_columns => qw/ title author genre borrower borrowed format isbn /);
+    __PACKAGE__->columns(view_columns => __PACKAGE__->columns("list_columns"), "publisher");
+
+
 Add crud configuration:
 
     __PACKAGE__->config(
@@ -456,8 +534,8 @@ look at the Book table. But why not run the tests again.
 
     prove -Ilib t
 
-All test should pass (and they don't really do much anyway. At least
-the Controller tests make a request to the default action).
+All test should pass (and they don't really do much anyway, but at
+least the Controller tests make a request to the default action).
 
 Run the server:
 
