@@ -76,7 +76,7 @@ Default: 20
 
 
 
-=head1 Class::DBI configuration
+=head1 CDBI CONFIGURATION
 
 =head2 Stringified column
 
@@ -98,20 +98,19 @@ to_field method.
 
 =head2 Fields to display
 
-  __PACKAGE__->columns(crud_view_columns => qw/ COLUMNS /);
+The following set of columns can be defined for various uses in the
+templates. The column names both define which columns to display, and
+in which order.
 
-Default: all columns.
+    __PACKAGE__->columns(view_columns => qw/ COLUMNS /);
+    __PACKAGE__->columns(edit_columns => qw/ COLUMNS /);
+    __PACKAGE__->columns(list_columns => qw/ COLUMNS /);
 
-(not yet implemented)
-
-=head2 Fields to display in lists
-
-  __PACKAGE__->columns(crud_list_columns => qw/ COLUMNS /);
-
-Default: all columns.
-
-(not yet implemented)
+The default is all columns except primary keys.
 
+These are pre-entered by the Model helper so it's easy for you to
+remove or change order. If you like it the way it is, just delete the
+lines altogether.
 
 
 =head1 EXAMPLE
@@ -183,12 +182,14 @@ sub default_column_moniker {
     my $pkg = shift;
     my ($column) = @_;
 
-    my $name = ucfirst(lc($column));
+    my $name = lc($column);
     $name =~ s/^id_//i;
     $name =~ s/_id$//i;
 
-    $name =~ s/(.)_+(.)/ "$1 " . uc($2) /e;
+    $name =~ s/(.)[_\s]+(.)/ "$1 " . uc($2) /eg;
 
+    $name = ucfirst($name);
+    
     return($name);
 }
 
@@ -196,6 +197,119 @@ sub default_column_moniker {
 
 
 
+=head2 list_columns()
+
+Return array with the column names suitable for a list of the objects
+in this Model.
+
+Configure this with:
+
+    __PACKAGE__->columns(list_columns => qw/ column names /);
+
+Default: the default_columns.
+
+=cut
+sub list_columns {
+    my $pkg = shift;
+    return($pkg->named_columns("list_columns"));
+}
+
+
+
+
+
+=head2 view_columns()
+
+Return array with the column names suitable for viewing an object in
+this Model.
+
+Configure this with:
+
+    __PACKAGE__->columns(view_columns => qw/ column names /);
+
+Default: the default_columns.
+
+=cut
+sub view_columns {
+    my $pkg = shift;
+    return($pkg->named_columns("view_columns"));
+}
+
+
+
+
+
+=head2 edit_columns()
+
+Return array with the column names suitable for editing an object in
+this Model.
+
+Configure this with:
+
+    __PACKAGE__->columns(edit_columns => qw/ column names /);
+
+Default: edit_columns (if specified), otherwise the default_columns.
+
+=cut
+sub edit_columns {
+    my $pkg = shift;
+
+    my @columns = $pkg->columns("view_columns");
+    @columns or @columns = $pkg->view_columns;
+    @columns or @columns = $pkg->default_columns();
+    
+    return(@columns);
+}
+
+
+
+
+
+=head2 named_columns($group_name)
+
+Return array with the column names identified by
+__PACKAGE__->columns($group_name).
+
+Configure this with:
+
+    __PACKAGE__->columns($group_name => qw/ column names /);
+
+=cut
+sub named_columns {
+    my $pkg = shift;
+    my ($group_name) = @_;
+
+    my @columns = $pkg->columns($group_name);
+    @columns or @columns = $pkg->default_columns();
+
+    return(@columns);
+}
+
+
+
+
+
+=head2 default_columns()
+
+Return array with the default column names suitable for an object in
+this Model.
+
+This is all column names, except PK columns.
+
+=cut
+sub default_columns {
+    my $pkg = shift;
+
+    my %pk_name_exists = map { $_ => 1 } $pkg->columns("Primary");
+    my @columns = grep { ! $pk_name_exists{$_} } $pkg->columns();
+    
+    return(@columns);
+}
+
+
+
+
+
 =head1 AUTHOR
 
 Johan Lindstrom <johanl T cpan.org>
